@@ -18,7 +18,7 @@
     <message>
         <location filename="../src/TxtReader.cpp" line="545"/>
         <source>&amp;Changes</source>
-        <translation>(&amp;C)更新日志</translation>
+        <translation>更新日志</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="272"/>
@@ -39,17 +39,17 @@ Perhaps it is not there, or you don&apos;t have access permission.</source>
     <message>
         <location filename="../src/TxtReader.cpp" line="277"/>
         <source>&amp;Close</source>
-        <translation>(&amp;C)关  闭</translation>
+        <translation>关  闭</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="333"/>
         <source>&amp;GB2312</source>
-        <translation>&amp;GB2312</translation>
+        <translation>GB2312</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="339"/>
         <source>&amp;UTF-8</source>
-        <translation>&amp;UTF-8</translation>
+        <translation>UTF-8</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="345"/>
@@ -114,7 +114,7 @@ Perhaps it is not there, or you don&apos;t have access permission.</source>
     <message>
         <location filename="../src/TxtReader.cpp" line="547"/>
         <source>&amp;Back</source>
-        <translation>(&amp;B)返  回</translation>
+        <translation>返  回</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="583"/>
@@ -155,27 +155,27 @@ Perhaps it is not there, or you don&apos;t have access permission.</source>
     <message>
         <location filename="../src/TxtReader.cpp" line="784"/>
         <source>&amp;Open</source>
-        <translation>(&amp;O)打  开</translation>
+        <translation>打  开</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="785"/>
         <source>&amp;Jump</source>
-        <translation>(&amp;J)跳  转</translation>
+        <translation>跳  转</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="788"/>
         <source>&amp;Rotate</source>
-        <translation>(&amp;R)旋转屏幕</translation>
+        <translation>旋转屏幕</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="804"/>
         <source>&amp;History</source>
-        <translation>(&amp;H)历史</translation>
+        <translation>历史</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="786"/>
         <source>&amp;Add Bookmark</source>
-        <translation>(&amp;A)添加书签</translation>
+        <translation>添加书签</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="544"/>
@@ -185,67 +185,67 @@ Perhaps it is not there, or you don&apos;t have access permission.</source>
     <message>
         <location filename="../src/TxtReader.cpp" line="790"/>
         <source>&amp;Find</source>
-        <translation>(&amp;F)查找</translation>
+        <translation>查找</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="791"/>
         <source>&amp;Next</source>
-        <translation>(&amp;N)下一个</translation>
+        <translation>下一个</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="792"/>
         <source>&amp;Zoom In</source>
-        <translation>(&amp;F)放  大</translation>
+        <translation>放  大</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="793"/>
         <source>&amp;Zoom Out</source>
-        <translation>(&amp;S)缩  小</translation>
+        <translation>缩  小</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="794"/>
         <source>&amp;Set Font</source>
-        <translation>(&amp;A)设  置</translation>
+        <translation>设  置</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="795"/>
         <source>&amp;Color</source>
-        <translation>(&amp;C)颜  色</translation>
+        <translation>颜  色</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="797"/>
         <source>&amp;Bg color</source>
-        <translation>(&amp;C)颜  色</translation>
+        <translation>颜  色</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="796"/>
         <source>&amp;Screen Light</source>
-        <translation>(&amp;L)背  光</translation>
+        <translation>背  光</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="798"/>
         <source>&amp;Bg image</source>
-        <translation>(&amp;B)图  片</translation>
+        <translation>图  片</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="799"/>
         <source>&amp;Reset</source>
-        <translation>(&amp;D)重  设</translation>
+        <translation>重  设</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="800"/>
         <source>&amp;Quit</source>
-        <translation>(&amp;Q)退  出</translation>
+        <translation>退  出</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="801"/>
         <source>&amp;About</source>
-        <translation>(&amp;A)关  于</translation>
+        <translation>关  于</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="809"/>
         <source>&amp;Search</source>
-        <translation>(&amp;S)搜  索</translation>
+        <translation>搜  索</translation>
     </message>
     <message>
         <source>&amp;Instruction</source>
@@ -271,41 +271,41 @@ Perhaps it is not there, or you don&apos;t have access permission.</source>
     <message>
         <location filename="../src/TxtReader.cpp" line="787"/>
         <source>&amp;Del Current</source>
-        <translation>(&amp;D)删除当前</translation>
+        <translation>删除当前</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="789"/>
         <source>&amp;Clear All</source>
-        <translation>(&amp;C)清除所有</translation>
+        <translation>清除所有</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="803"/>
         <source>&amp;Language</source>
-        <translation>&amp;Language</translation>
+        <translation>Language</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="805"/>
         <source>&amp;Bookmark</source>
-        <translation>(&amp;B)书  签</translation>
+        <translation>书  签</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="806"/>
         <source>&amp;Font</source>
-        <translation>(&amp;F)字  体</translation>
+        <translation>字  体</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="807"/>
         <source>&amp;Background</source>
-        <translation>(&amp;B)背  景</translation>
+        <translation>背  景</translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="808"/>
         <source>&amp;Codec</source>
-        <translation>(&amp;C)编  码</translation>
+        <translation>编  码</translation>
     </message>
     <message>
         <source>&amp;Go Back</source>
-        <translation type="obsolete">(&amp;G)返回阅读</translation>
+        <translation type="obsolete">返回阅读</translation>
     </message>
 </context>
 </TS>
