@@ -1,12 +1,11 @@
 #include "TxtReader.h"
-#include <QtGui>
 #include <libosso.h>
 
 osso_context_t *oss = NULL;
 
 TxtReader::TxtReader(QString infile)
 {
-        version = QString("0.6.7");
+        version = QString("0.6.8");
         setWindowTitle( QString("TXTReader %1").arg(version));
         qApp->installTranslator(&appTranslator);
         oss = osso_initialize("txtreader", "0.6.7", FALSE, NULL);
@@ -268,7 +267,6 @@ void TxtReader::showChanges(){
     in.setCodec("UTF-8");
 
     QDialog changesDialog;
-    changesDialog.setWindowIcon(this->windowIcon());
     changesDialog.setWindowTitle(tr("TxtReader Changes"));
     QGridLayout l;
     QTextEdit t;
@@ -279,7 +277,8 @@ void TxtReader::showChanges(){
     l.addWidget(&t);
     l.addWidget(&b,1,0,Qt::AlignRight);
     changesDialog.setLayout(&l);
-//    changesDialog.resize(400,300);
+    if(!isLandscape)
+      changesDialog.setAttribute(static_cast<Qt::WidgetAttribute>(128),true);
     changesDialog.exec();
 }
 
@@ -543,15 +542,19 @@ void TxtReader::about()
     QLabel t;
     t.setText(tr("<p align=center>Txt Reader %1 </p><p align=center> Design by <a href='http://code.google.com/p/txtreader4linux' target=_blank>lsyer</a></p><p align=center>CopyLeft(C)2006-YEAR</p><p align=center>Eveing 为 N900 移植</p>").arg(version));
     QPushButton c(tr("&Changes"));
+    c.setMinimumSize(190,70);
     connect(&c,SIGNAL(clicked()),this,SLOT(showChanges()));
     QPushButton b(tr("&Back"),this);
+    b.setMinimumSize(190,70);
     connect(&b,SIGNAL(clicked()),&aboutDialog,SLOT(close()));
     b.setFocus();
-    l.addWidget(&t,0,1,1,2,Qt::AlignCenter);
-    l.addWidget(&c,1,0,1,2,Qt::AlignCenter);
-    l.addWidget(&b,1,2,Qt::AlignCenter);
+    l.addWidget(&t,0,0,2,1,Qt::AlignCenter);
+    l.addWidget(&c,0,1,1,1,Qt::AlignRight);
+    l.addWidget(&b,1,1,1,1,Qt::AlignRight);
     aboutDialog.setLayout(&l);
     aboutDialog.setFixedSize(aboutDialog.sizeHint());
+    if(!isLandscape)
+      aboutDialog.setAttribute(static_cast<Qt::WidgetAttribute>(128),true);
     aboutDialog.exec();
 
     return ;
@@ -578,34 +581,55 @@ void TxtReader::setcodecstr(QAction *action)
 }
 void TxtReader::slotJumpToPage()
 {
-     bool ok;
-     int i = QInputDialog::getInteger(this, QString("Txt Reader %1").arg(version),
-                                          tr("Jump to:"), curPageNum,1,TotalPageNum,1, &ok);
-     if (ok){
-         jumpToPage(i);
-         curOffset = PageOffsetList[curPageNum-1];
-     }
-
-    return ;
+    QDialog d;
+    d.setWindowTitle(tr("Jump to:"));
+    QGridLayout l;
+    QSlider t;
+    t.setOrientation(Qt::Horizontal);
+    t.setRange(1,TotalPageNum);
+    t.setValue(curPageNum);
+    QPushButton b(tr("&Jump"),this);
+    connect(&b,SIGNAL(clicked()),&d,SLOT(accept()));
+    l.addWidget(&t);
+    l.addWidget(&b,0,1,Qt::AlignRight);
+    d.setLayout(&l);
+    if(!isLandscape)
+      d.setAttribute(static_cast<Qt::WidgetAttribute>(128),true);
+    if(d.exec() == QDialog::Accepted){
+      int i = t.value();
+      if(i != curPageNum){
+        jumpToPage(i);
+        curOffset = PageOffsetList[curPageNum-1];
+      }
+    }
 }
 void TxtReader::slotSearchOri()
 {
-    bool ok;
-    searchText = QInputDialog::getText(this, QString("Txt Reader %1").arg(version),
-                                         tr("Search:"), QLineEdit::Normal,searchText, &ok);
-    if ( ok && !(searchText.isNull()) ){
-        int pos=FileContent.indexOf(searchText);
+    QDialog d;
+    d.setWindowTitle("Search:");
+    QGridLayout l;
+    QLineEdit t;
+    QPushButton b(tr("&Search"),this);
+    connect(&b,SIGNAL(clicked()),&d,SLOT(accept()));
+    l.addWidget(&t);
+    l.addWidget(&b,0,1,Qt::AlignRight);
+    d.setLayout(&l);
+    if(!isLandscape)
+      d.setAttribute(static_cast<Qt::WidgetAttribute>(128),true);
+    if(d.exec() == QDialog::Accepted){
+      searchText = t.displayText();
+      if ( !(searchText.isEmpty()) ){
+        int pos=FileContent.indexOf(searchText,curOffset + 1);
         if(pos != -1){
             jumpToOffset(pos);
             curOffset = pos;
         }
+      }
     }
-
-   return ;
 }
 void TxtReader::slotSearchCur()
 {
-    if ( !(searchText.isNull()) ){
+    if ( !(searchText.isEmpty()) ){
         int pos=FileContent.indexOf(searchText,curOffset + 1);
         if(pos != -1){
             jumpToOffset(pos);
@@ -617,18 +641,29 @@ void TxtReader::slotSearchCur()
 }
 void TxtReader::addBookmark()
 {
-	bool ok;
-        QString text = QInputDialog::getText(this, QString("Txt Reader %1").arg(version),
-                                          tr("Please input the mark:"), QLineEdit::Normal,
-                                          tr("%1").arg(curPageNum), &ok);
-	if (ok && !text.isEmpty()){
+    QString text;
+    QDialog d;
+    d.setWindowTitle(tr("Please input the mark:"));
+    QGridLayout l;
+    QLineEdit t;
+    t.setText(tr("%1").arg(curPageNum));
+    QPushButton b(tr("&Add Bookmark"),this);
+    connect(&b,SIGNAL(clicked()),&d,SLOT(accept()));
+    l.addWidget(&t);
+    l.addWidget(&b,0,1,Qt::AlignRight);
+    d.setLayout(&l);
+    if(!isLandscape)
+      d.setAttribute(static_cast<Qt::WidgetAttribute>(128),true);
+    if(d.exec() == QDialog::Accepted){
+        text = t.displayText();
+	if ( !text.isEmpty()){
                 QAction * bookmark = new QAction(tr("%1").arg(text), this);
                 bookmark->setData(PageOffsetList[curPageNum-1]);
 		connect(bookmark, SIGNAL(triggered()), this, SLOT(openBookmark()));
                 bookmarkArray.append(bookmark);
 		bookmarkMenu->addAction(bookmark);
 	}
-	return ;
+    }
 }
 void TxtReader::delBookmark()
 {
